@@ -113,7 +113,7 @@ _default_options_objects = [
     },
     {
         'name': 'API_KEYS_DB_PATH',
-        'default_value': 'api_keys.db',
+        'default_value': 'db/api_keys.db',
         'value_type': 'str'
     },
     {
@@ -156,6 +156,11 @@ _default_options_objects = [
         'default_value': False,
         'value_type': 'bool'
     },
+    {
+        'name': 'UPDATE_MODELS',
+        'default_value': False,
+        'value_type': 'bool'
+    },
 ]
 
 
