@@ -1,7 +1,7 @@
 import string
 
 from argostranslate import translate
-from polyglot.detect.base import Detector, UnknownLanguage
+from app.detect import Detector, UnknownLanguage
 
 __languages = None
 
@@ -83,7 +83,10 @@ def improve_translation_formatting(source, translation, improve_punctuation=True
 
     if not len(source):
         return ""
-
+    
+    if not len(translation):
+        return source
+    
     if improve_punctuation:
         source_last_char = source[len(source) - 1]
         translation_last_char = translation[len(translation) - 1]
